#
# spec file for package tik
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tik
Version:        1.0.4
Release:        1.1
Summary:        Transactional Installation Kit
License:        MIT
URL:            https://github.com/sysrich/tik
Source:         %{name}-%{version}.tar.xz
BuildArch:      noarch
Requires:       coreutils
Requires:       dbus-1-tools
Requires:       efibootmgr
Requires:       grep
Requires:       pkexec
Requires:       pv
Requires:       tik-config
Requires:       util-linux
Requires:       util-linux-systemd
Requires:       xz
Requires:       zenity

%description
A toolkit for deploying Operating System images to UEFI hardware from a USB stick.

%package config-generic
Summary:        Generic configuration for tik
Requires:       tik
Conflicts:      tik-config
Provides:       tik-config

%description config-generic
Generic configuration for tik. To be used for "distribution neutral" installation media or debug/experimentation.

%package module-welcome
Summary:        Welcome module for tik
Requires:       tik

%description module-welcome
Welcome module for tik. Greets the user before installation.

%package module-mig
Summary:        Migration module for tik
Requires:       tik

%description module-mig
Migration module for tik. Detects existing btrfs /home subvolumes and offers to backup/restore it using the tik USB stick.

%prep
%autosetup

%build

%install
install -D -m 755 usr/bin/tik %{buildroot}%{_bindir}/tik
install -D -m 644 usr/lib/tik/config %{buildroot}%{_prefix}/lib/tik/config
install -D -m 644 usr/lib/tik/lib/tik-functions %{buildroot}%{_prefix}/lib/tik/lib/tik-functions
install -D -m 644 etc/tik/config %{buildroot}%{_sysconfdir}/tik/config
install -d %{buildroot}%{_prefix}/lib/tik/modules/pre
install -d %{buildroot}%{_prefix}/lib/tik/modules/post
install -d %{buildroot}%{_prefix}/lib/tik/img
install -d %{buildroot}%{_sysconfdir}/tik/modules/pre
install -d %{buildroot}%{_sysconfdir}/tik/modules/post

install -D -m 644 usr/lib/tik/modules/pre/10-welcome %{buildroot}%{_prefix}/lib/tik/modules/pre

install -D -m 644 usr/lib/tik/modules/pre/20-mig %{buildroot}%{_prefix}/lib/tik/modules/pre
install -D -m 644 usr/lib/tik/modules/post/20-mig %{buildroot}%{_prefix}/lib/tik/modules/post

%files
%license LICENSE
%doc README.md
%dir %{_prefix}/lib/tik
%dir %{_prefix}/lib/tik/modules
%dir %{_prefix}/lib/tik/modules/pre
%dir %{_prefix}/lib/tik/modules/post
%dir %{_prefix}/lib/tik/img
%dir %{_prefix}/lib/tik/lib
%{_prefix}/lib/tik/lib/tik-functions
%{_bindir}/tik

%files config-generic
%{_prefix}/lib/tik/config
%dir %{_sysconfdir}/tik
%dir %{_sysconfdir}/tik/modules
%dir %{_sysconfdir}/tik/modules/pre
%dir %{_sysconfdir}/tik/modules/post
%config(noreplace) %{_sysconfdir}/tik/config

%files module-welcome
%{_prefix}/lib/tik/modules/pre/10-welcome

%files module-mig
%{_prefix}/lib/tik/modules/pre/20-mig
%{_prefix}/lib/tik/modules/post/20-mig

%changelog
* Mon May 27 2024 rbrown@suse.com
- Update to version 1.0.4:
  * module-mig: filter out empty SD card readers from install target list
* Fri May 24 2024 rbrown@suse.com
- Update to version 1.0.3:
  * module-mig: make /etc umount optional - doesn't mount on Leap/TW sources
* Fri May 24 2024 rbrown@suse.com
- Update to version 1.0.2:
  * Put autostart .desktop in migrated homedirs
* Wed May 22 2024 rbrown@suse.com
- Update to version 1.0.1:
  * Force all migrated users to have default shell of /bin/bash
  * module-mig: Cleanup incomplete snapshot
  * migration: probe for existing LUKS devices, and ask the user to unlock them
  * Correct copyright attribution
* Thu May 16 2024 rbrown@suse.com
- Update to version 0.9.5:
  * module-welcome: change echo to log
  * Set boot target after all modules
  * If restoring btrfs containers, set container storage driver to btrfs
  * Moved AC power detection function after the welcome message
  * Apply suggestions from code review
  * Update 10-welcome
  * Added code to detect laptop is connected to AC power before proceeding to copy home files to flash drive and starting upgrade
* Wed May 15 2024 rbrown@suse.com
- Update to version 0.9.4:
  * module-mig: backup nested btrfs subvolumes and groups also
  * module-mig: Also backup/restore subgid/subuid
* Tue May 14 2024 rbrown@suse.com
- Update to version 0.9.3:
  * module-mig: chmod copy of AccountsService/users so it can be properly copied and cleaned up
* Mon May 13 2024 rbrown@suse.com
- Update to version 0.9.2:
  * Consider AccountsService info as optional
  * Support migrating existing user local & system time settings
* Mon May 13 2024 rbrown@suse.com
- Update to version 0.9.1:
  * module-mig: Legacy Aeon: look for a file that will actually be on legacy Aeon installs
* Mon May 13 2024 rbrown@suse.com
- Update to version 0.9.0:
  * Don't auto-close errors, gives the user time to debug
  * Introduce prun-opt function, make all other prun calls mandatory to exit cleanly
* Wed May  8 2024 rbrown@suse.com
- Update to version 0.2.2:
  * tik-functions: restore wiping the bootorder, be more cautious about other bootentries
* Wed May  8 2024 rbrown@suse.com
- Update to version 0.2.1:
  * module-mig: Correct nm config restore location
* Tue May  7 2024 rbrown@suse.com
- Update to version 0.2.0:
  * module-mig: improve prun calls
  * module-mig: change eval parameter ordering
  * module-mig: bugfix - find existing backup if mig_dir is not empty
  * module-mig: bugfix - create mig_dir if doesn't exist, not if it does
* Tue May  7 2024 rbrown@suse.com
- Update to version 0.1.7:
  * New Migration Module
  * module-pre-10-welcome: initial welcome module
* Mon May  6 2024 rbrown@suse.com
- Update to version 0.1.6:
  * Correct efibootmgr path
* Mon May  6 2024 rbrown@suse.com
- Update to version 0.1.5:
  * set_boot_target: Set (and log) the boot target for the newly installed image
  * Remove unused variable: image_basename
* Mon May  6 2024 Richard Brown <rbrown@suse.com>
- Require efibootmgr
* Thu May  2 2024 rbrown@suse.com
- Update to version 0.1.4:
  * Tidy up exit trap and zenity dialogs using spanning
  * Log module behaviour more cleanly
  * reassign the right disk_id type when restoring the device path
  * improve disk dialog, show only disk ID without path
* Thu May  2 2024 rbrown@suse.com
- Update to version 0.1.3:
  * Improve layout of disk selection window
* Thu May  2 2024 Richard Brown <rbrown@suse.com>
- Create and own modules directories
* Thu May  2 2024 rbrown@suse.com
- Update to version 0.1.2:
  * Improve all dialogs, inspired by https://gitlab.gnome.org/Teams/Design/os-mockups/-/raw/master/installer/os-installer.png
  * Correctly log when using predefined device/image
  * Indentation cleanups & logging improvement
  * zenity: also log returned value, good to debug what menu option was picked
  * exit messages shouldn't trap non-zero codes as errors, also no need to log
  * Tidy up and make logs more consistent
* Thu May  2 2024 Richard Brown <rbrown@suse.com>
- pv required for progress info
* Wed May  1 2024 Richard Brown <rbrown@suse.com>
- Rework spec for version 0.1.0
* Wed May  1 2024 rbrown@suse.com
- Update to version 0.1.0:
  * prun: use full paths for pkexec
  * tik-gui: First commit, core functionality working
* Thu Apr 25 2024 rbrown@suse.com
- Update to version 0.0.10:
  * Reboot when finished
  * Make some boxes bigger
* Thu Apr 25 2024 rbrown@suse.com
- Update to version 0.0.9:
  * Avoid scaling message boxes, looks ugly
* Thu Apr 25 2024 rbrown@suse.com
- Update to version 0.0.8:
  * Scale boxes that need to scale
* Wed Apr 24 2024 rbrown@suse.com
- Update to version 0.0.7:
  * Standardise on scaling height where it makes sense
* Wed Apr 24 2024 rbrown@suse.com
- Update to version 0.0.6:
  * Correct dd output
* Wed Apr 24 2024 rbrown@suse.com
- Update to version 0.0.5:
  * Standardise on 80 character wide boxes
  * Properly sync the image
- Remove pv again, breaks more than it helps
* Mon Apr 22 2024 Richard Brown <rbrown@suse.com>
- Added pv back - useful for modules
* Sun Apr 21 2024 Richard Brown <rbrown@suse.com>
- No longer use pv (not used by 0.0.4)
* Sat Apr 20 2024 rbrown@suse.com
- Update to version 0.0.4:
  * Better find images and show more robust progress
* Thu Apr  4 2024 Richard Brown <rbrown@suse.com>
- Add systemd service
* Thu Apr  4 2024 rbrown@suse.com
- Update to version 0.0.3:
  * Fix Issue #1 - correct error reporting, and properly use xz
* Tue Mar 26 2024 rbrown@suse.com
- Update to version 0.0.2:
  * Add systemd unit
  * Normalise /etc and /usr configs
* Mon Mar 25 2024 sfalken@opensuse.org
- Specfile cleanup, clearing rpmlint warnings/errors
* Mon Mar 25 2024 rbrown@suse.com
- Version 0.0.1: Initial package
